pub enum SearchAlgorithm {
SingleSourceShortestPath {
termination_behavior: TerminationFailurePolicy,
a_star: bool,
},
KspSingleVia {
k: usize,
underlying: Box<SearchAlgorithm>,
similarity: Option<RouteSimilarityFunction>,
termination: Option<KspTerminationCriteria>,
},
Yens {
k: usize,
underlying: Box<SearchAlgorithm>,
similarity: Option<RouteSimilarityFunction>,
termination: Option<KspTerminationCriteria>,
},
}Variants
SingleSourceShortestPath
algorithm to support classic SSSP algorithms such as Dijkstra’s and A*.
Fields
termination_behavior: TerminationFailurePolicyif the termination model returns early, treat it as a search error. if false, the result is still returned. this option is not valid for searches without destinations (path searches).
KspSingleVia
KSP using the single via paths algorithm.
Fields
underlying: Box<SearchAlgorithm>path search algorithm to use
similarity: Option<RouteSimilarityFunction>if provided, filters out potential solution paths based on their similarity to the paths in the stored result set
termination: Option<KspTerminationCriteria>termination criteria for the inner path search function
Yens
KSP using Yen’s Algorithm
Fields
underlying: Box<SearchAlgorithm>path search algorithm to use
similarity: Option<RouteSimilarityFunction>if provided, filters out potential solution paths based on their similarity to the paths in the stored result set
termination: Option<KspTerminationCriteria>termination criteria for the inner path search function
Implementations
Sourceimpl SearchAlgorithm
impl SearchAlgorithm
pub fn run_vertex_oriented( &self, src_id: VertexId, dst_id_opt: Option<VertexId>, query: &Value, direction: &Direction, si: &SearchInstance, ) -> Result<SearchAlgorithmResult, SearchError>
pub fn run_edge_oriented( &self, src: (EdgeListId, EdgeId), dst_opt: Option<(EdgeListId, EdgeId)>, query: &Value, direction: &Direction, si: &SearchInstance, ) -> Result<SearchAlgorithmResult, SearchError>
Sourcepub fn cost_constraint(&self) -> CostConstraint
pub fn cost_constraint(&self) -> CostConstraint
constraint applied to cost values due to the type of algorithm run.