pub enum SearchTreeNode {
Root {
direction: Direction,
},
Branch {
incoming_edge: EdgeTraversal,
parent: Label,
direction: Direction,
},
}Expand description
A node in the search tree containing parent/child relationships and traversal data
Variants
Implementations
Sourceimpl SearchTreeNode
impl SearchTreeNode
Sourcepub fn new_child(
incoming_edge: EdgeTraversal,
parent: Label,
direction: Direction,
) -> Self
pub fn new_child( incoming_edge: EdgeTraversal, parent: Label, direction: Direction, ) -> Self
create a new child node from some trajectory (parent) -> [incoming_edge] -> (), for some direction in the network.
Sourcepub fn parent_label(&self) -> Option<&Label>
pub fn parent_label(&self) -> Option<&Label>
Retrieves the label of the parent node, if this node is not the root.
Sourcepub fn incoming_edge(&self) -> Option<&EdgeTraversal>
pub fn incoming_edge(&self) -> Option<&EdgeTraversal>
Retrieves the edge traversal that led to this node, if this node is not the root.
Sourcepub fn direction(&self) -> Direction
pub fn direction(&self) -> Direction
Retrieves the direction of the search tree this node belongs to.
Sourcepub fn traversal_cost(&self) -> Option<&TraversalCost>
pub fn traversal_cost(&self) -> Option<&TraversalCost>
Retrieves the cost of the edge traversal that led to this node, if this node is not the root.