pub struct SearchResult {
pub tree: SearchTree,
pub iterations: u64,
pub terminated: Option<String>,
}Expand description
the result of running a super::SearchAlgorithm.
Fields
tree: SearchTreethe tree created by the search algorithm
iterations: u64number of iterations run to create this tree
terminated: Option<String>if present, a message explaining a forced termination of the search. if not present, the search terminated naturally by reaching an empty frontier state.
Implementations
Sourceimpl SearchResult
impl SearchResult
Sourcepub fn completed(tree: SearchTree, iterations: u64) -> SearchResult
pub fn completed(tree: SearchTree, iterations: u64) -> SearchResult
create a SearchResult for a search that completed, aka, which reached
an empty frontier state.
Sourcepub fn terminated(
tree: SearchTree,
iterations: u64,
explanation: String,
) -> SearchResult
pub fn terminated( tree: SearchTree, iterations: u64, explanation: String, ) -> SearchResult
create a SearchResult for a search that was forced to terminate by the
crate::model::termination::TerminationModel. include a message explaining the
reason it was terminated.