pub struct EdgeCutConstraintModel {
pub underlying: Arc<dyn ConstraintModel>,
/* private fields */
}Expand description
A wrapper of the user-generated ConstraintModel which prohibits traversals on selected edges. algorithms can create this wrapper with a set of “cut edges” and the search will not allow traversal of these edges.
Fields
underlying: Arc<dyn ConstraintModel>Implementations
Sourceimpl EdgeCutConstraintModel
impl EdgeCutConstraintModel
pub fn new( underlying: Arc<dyn ConstraintModel>, cut_edges: HashSet<EdgeId>, ) -> EdgeCutConstraintModel