pub struct MapModel {
pub matching_type: MatchingType,
pub spatial_index: SpatialIndex,
pub geometry: Vec<GeometryModel>,
pub queries_without_destinations: bool,
pub config: MapModelConfig,
}Fields
matching_type: MatchingTypeway in which map matching is attempted
spatial_index: SpatialIndexindex used during map matching
geometry: Vec<GeometryModel>collection of geometries associated with the graph edge lists
queries_without_destinations: boolallow for queries without a destination location, such as when generating shortest path trees or isochrones.
config: MapModelConfigthe configuration used to create this map model
Implementations
Sourceimpl MapModel
impl MapModel
pub fn new( graph: Arc<Graph>, config: MapModelConfig, ) -> Result<MapModel, MapError>
pub fn get_linestring<'a>( &'a self, edge_list_id: &EdgeListId, edge_id: &EdgeId, ) -> Result<&'a LineString<f32>, MapError>
pub fn map_match( &self, query: &mut Value, si: &SearchInstance, ) -> Result<(), MapError>