pub struct MapModelConfig {
pub tolerance: Option<DistanceTolerance>,
pub spatial_index_type: Option<SpatialIndexType>,
pub matching_type: Option<Vec<String>>,
pub geometry: OneOrMany<MapModelGeometryConfig>,
pub queries_without_destinations: bool,
}Fields
tolerance: Option<DistanceTolerance>distance from coordinate to the nearest vertex required for map matching
spatial_index_type: Option<SpatialIndexType>geometries to place in the spatial index used for map matching.
matching_type: Option<Vec<String>>the [MatchingType]s supported
geometry: OneOrMany<MapModelGeometryConfig>for each edge list, geometry configuration
queries_without_destinations: boolallow source-only queries for shortest path tree outputs