Graph

Struct Graph 

pub struct Graph {
    pub vertices: Box<[Vertex]>,
    pub edge_lists: Vec<EdgeList>,
    pub adj: Box<[IndexMap<(EdgeListId, EdgeId), VertexId>]>,
    pub rev: Box<[IndexMap<(EdgeListId, EdgeId), VertexId>]>,
}
Road network topology represented as an adjacency list. The EdgeId and VertexId values correspond to edge and vertex indices in the edges and vertices vectors.

Arguments

  • adj - the forward-oriented adjacency list
  • rev - the reverse-oriented adjacency list
  • edges - for each EdgeId, the corresponding Edge record
  • vertices - for each VertexId, the corresponding Vertex record

Performance

Methods provided via the Graph type prefer avoiding copies. Operations on a single entity should be O(1). Most methods returning collections will prefer chained iterators. A few will collect into Vecs because of error handling or lifetimes, but those cases will only produce a smaller subset of the source data.

Fields

vertices: Box<[Vertex]>edge_lists: Vec<EdgeList>adj: Box<[IndexMap<(EdgeListId, EdgeId), VertexId>]>rev: Box<[IndexMap<(EdgeListId, EdgeId), VertexId>]>

Implementations

Source

impl Graph

pub fn get_edge_list( &self, edge_list_id: &EdgeListId, ) -> Result<&EdgeList, NetworkError>

access a specific EdgeList by its id

pub fn n_edge_lists(&self) -> usize

pub fn n_edges(&self) -> usize

number of edges in the Graph, not to be conflated with the list of edge ids

pub fn n_vertices(&self) -> usize

number of vertices in the Graph

pub fn edge_ids( &self, edge_list_id: &EdgeListId, ) -> Result<Box<dyn Iterator<Item = EdgeId>>, NetworkError>

helper function for creating a range of all edge ids in the graph. uses the knowledge that all ids are unique and consecutive integers beginning at zero.

pub fn vertex_ids(&self) -> Box<dyn Iterator<Item = VertexId>>

helper function for creating a range of all vertex ids in the graph. uses the knowledge that all ids are unique and consecutive integers beginning at zero.

pub fn edges<'a>(&'a self) -> Box<dyn Iterator<Item = &'a Edge> + 'a>

iterates through all edges in the graph

pub fn get_edge( &self, edge_list_id: &EdgeListId, edge_id: &EdgeId, ) -> Result<&Edge, NetworkError>

retrieve an Edge record from the graph

Arguments
  • edge_id - the EdgeId for the Edge that we want to retrieve
Returns

The associated Edge or an error if the id is missing

pub fn get_vertex(&self, vertex_id: &VertexId) -> Result<&Vertex, NetworkError>

retrieve a Vertex record from the graph

Arguments
  • vertex_id - the VertexId for the Vertex that we want to retrieve
Returns

The associated Vertex or an error if the id is missing

pub fn out_edges(&self, src: &VertexId) -> Vec<(EdgeListId, EdgeId)>

retrieve a list of EdgeIds for edges that depart from the given VertexId

Arguments
  • src - the VertexId for the source vertex of edges
Returns

A list of EdgeIds for outbound edges that leave this VertexId, or an error if the vertex is missing from the Graph adjacency matrix.

pub fn out_edges_iter<'a>( &'a self, src: &'a VertexId, ) -> Box<dyn Iterator<Item = &'a (EdgeListId, EdgeId)> + 'a>

builds an iterator

pub fn in_edges(&self, dst: &VertexId) -> Vec<(EdgeListId, EdgeId)>

retrieve a list of EdgeIds for edges that arrive at the given VertexId

Arguments
  • dst - the VertexId for the destination vertex of edges
Returns

A list of EdgeIds for inbound edges that arrive at this VertexId, or an error if the vertex is missing from the Graph adjacency matrix.

pub fn in_edges_iter<'a>( &'a self, src: &'a VertexId, ) -> Box<dyn Iterator<Item = &'a (EdgeListId, EdgeId)> + 'a>

pub fn src_vertex_id( &self, edge_list_id: &EdgeListId, edge_id: &EdgeId, ) -> Result<VertexId, NetworkError>

retrieve the source vertex id of an edge

Arguments
  • edge_id - the edge to find a source vertex id
Returns

The source VertexId of an Edge or an error if the edge is missing

pub fn dst_vertex_id( &self, edge_list_id: &EdgeListId, edge_id: &EdgeId, ) -> Result<VertexId, NetworkError>

retrieve the destination vertex id of an edge

Arguments
  • edge_id - the edge to find a destination vertex id
Returns

The destination VertexId of an Edge or an error if the edge is missing

pub fn incident_edges( &self, vertex_id: &VertexId, direction: &Direction, ) -> Vec<(EdgeListId, EdgeId)>

helper function to give incident edges to a vertex based on a traversal direction.

Arguments
  • vertex_id - vertex to find edges which connect to it
  • direction - whether to find out edges (Forward) or in edges (Reverse)
Returns

The incident EdgeIds or an error if the vertex is not connected.

pub fn incident_edges_iter<'a>( &'a self, vertex_id: &'a VertexId, direction: &Direction, ) -> Box<dyn Iterator<Item = &'a (EdgeListId, EdgeId)> + 'a>

helper function to give incident edges to a vertex based on a traversal direction.

Arguments
  • vertex_id - vertex to find edges which connect to it
  • direction - whether to find out edges (Forward) or in edges (Reverse)
Returns

The incident EdgeIds or an error if the vertex is not connected.

pub fn incident_vertex( &self, edge_list_id: &EdgeListId, edge_id: &EdgeId, direction: &Direction, ) -> Result<VertexId, NetworkError>

helper function to give the incident vertex to an edge based on a traversal direction.

Arguments
  • edge_id - edge to find the vertex which connects to it
  • direction - whether to find the destination (Forward) or source (Reverse) vertex
Returns

The incident VertexId of an edge or an error if the edge is missing

pub fn edge_triplet( &self, edge_list_id: &EdgeListId, edge_id: &EdgeId, ) -> Result<(&Vertex, &Edge, &Vertex), NetworkError>

retrieve the triplet of Vertex -> Edge -> Vertex for some EdgeId

Arguments
  • edge_id - the id of the edge to collect attributes for
returns

The triplet of attributes surrounding one Edge or an error if any id is invalid.

pub fn incident_triplet_ids( &self, vertex_id: &VertexId, direction: &Direction, ) -> Result<Vec<(VertexId, EdgeListId, EdgeId, VertexId)>, NetworkError>

creates VertexId -> EdgeId -> VertexId triplets based on a VertexId and a traversal Direction.

Regardless of the direction chosen, the source VertexId appears first and the terminal VertexId appears in the third slot.

Arguments
  • vertex_id - id of the vertex to lookup incident triplets
  • direction - direction to traverse to/from the vertex_id
Returns

For each edge connected to this vertex_id traversable via the provided direction, a triplet of the EdgeId and it’s connecting VertexIds.

pub fn incident_triplet_attributes( &self, vertex_id: &VertexId, direction: &Direction, ) -> Result<Vec<(&Vertex, &Edge, &Vertex)>, NetworkError>

creates Vertex -> Edge -> Vertex triplets based on a Vertex and a traversal Direction.

Regardless of the direction chosen, the source Vertex appears first and the terminal Vertex appears in the third slot.

Arguments
  • vertex_id - id of the vertex to lookup incident triplets
  • direction - direction to traverse to/from the vertex_id
Returns

For each edge connected to this vertex_id traversable via the provided direction, a triplet of the Edge and it’s connecting Vertexs.