pub struct GraphConfig {
pub vertex_list_input_file: String,
pub edge_list: OneOrMany<EdgeListConfig>,
}Fields
vertex_list_input_file: Stringedge_list: OneOrMany<EdgeListConfig>Trait Implementations
Sourceimpl Clone for GraphConfig
impl Clone for GraphConfig
Sourcefn clone(&self) -> GraphConfig
fn clone(&self) -> GraphConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphConfig
impl Debug for GraphConfig
Sourceimpl<'de> Deserialize<'de> for GraphConfig
impl<'de> Deserialize<'de> for GraphConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for GraphConfig
impl Serialize for GraphConfig
Sourceimpl TryFrom<&GraphConfig> for Graph
impl TryFrom<&GraphConfig> for Graph
Sourcefn try_from(config: &GraphConfig) -> Result<Self, Self::Error>
fn try_from(config: &GraphConfig) -> Result<Self, Self::Error>
create a graph from a JSON argument. it should be an object that contains two keys, one for each file path.
Sourcetype Error = NetworkError
type Error = NetworkError
The type returned in the event of a conversion error.