CustomVariableConfig

Enum CustomVariableConfig 

pub enum CustomVariableConfig {
    FloatingPoint {
        initial: OrderedFloat<f64>,
    },
    SignedInteger {
        initial: i64,
    },
    UnsignedInteger {
        initial: u64,
    },
    Boolean {
        initial: bool,
    },
}
codec between StateVar values and basic Rust types. all stateful information in Compass is encoded as a vector of floating point values. a codec provides a mapping to and from types in order to represent different real-numbered and discrete information types.

because Rust does not support dependent types and trait objects cannot return “Self“s, we are limited in how we generalize over unit types. these codecs substitute for the limitations in the type system, providing a validation check on encoding and decoding to/from StateVar instances and also a codec value that can be instantiated from configuration for a given StateModel.

warning: this could backfire, but probably in extreme cases that can be avoided. for example, if the user selects esoteric integer values that are not well-represented in floating point, then an encode -> decode roundtrip may not be idempotent.

Variants



FloatingPoint

Fields



SignedInteger

Fields

initial: i64


UnsignedInteger

Fields

initial: u64


Boolean

Fields

initial: bool

Implementations