pub enum InputFeature {
Distance {
name: String,
unit: Option<DistanceUnit>,
},
Speed {
name: String,
unit: Option<SpeedUnit>,
},
Time {
name: String,
unit: Option<TimeUnit>,
},
Energy {
name: String,
unit: Option<EnergyUnit>,
},
Ratio {
name: String,
unit: Option<RatioUnit>,
},
Temperature {
name: String,
unit: Option<TemperatureUnit>,
},
Custom {
name: String,
unit: String,
},
}Expand description
defines the required input feature and its requested unit type for a given state variable
if a unit type is provided, then the state variable is provided in the requested unit to the model.
Variants
Implementations