pub struct DriverReadOnlyLock<T> { /* private fields */ }Expand description
there are no read-only locks in the existing rust library that prevent executors from having write access. this pair of classes allows a driver application to instantiate a RwLock on an object, and then issue read-only clones of that lock to executors in a parallel setup.
see https://stackoverflow.com/a/68908523
Implementations
Sourceimpl<T> DriverReadOnlyLock<T>
impl<T> DriverReadOnlyLock<T>
pub fn new(val: T) -> Self
pub fn write(&self) -> LockResult<RwLockWriteGuard<'_, T>>
pub fn read(&self) -> LockResult<RwLockReadGuard<'_, T>>
pub fn read_only(&self) -> ExecutorReadOnlyLock<T>