pub enum SearchAlgorithmConfig {
Dijkstras {
termination_behavior: Option<TerminationFailurePolicy>,
},
AStar {
termination_behavior: Option<TerminationFailurePolicy>,
},
KspSingleVia {
k: usize,
underlying: Box<SearchAlgorithmConfig>,
similarity: Option<RouteSimilarityFunction>,
termination: Option<KspTerminationCriteria>,
},
Yens {
k: usize,
underlying: Box<SearchAlgorithmConfig>,
similarity: Option<RouteSimilarityFunction>,
termination: Option<KspTerminationCriteria>,
},
}Variants
Dijkstras
Edgard Dijkstra’s breadth first search algorithm, implemented as A* with a zero-valued cost estimate function.
Fields
termination_behavior: Option<TerminationFailurePolicy>optional argument to define handling of terminated searches
AStar
Classic best-first search algorithm.
Fields
termination_behavior: Option<TerminationFailurePolicy>optional argument to define handling of terminated searches
KspSingleVia
K-shortest paths algorithm that relies on a novel bidirectional search algorithm combined with a map-algebraic heuristic to identify midpoints on approximate ksp paths. Taken from the paper Häcker, Christian, et al. “Most diverse near-shortest paths.” Proceedings of the 29th International Conference on Advances in Geographic Information Systems. 2021.
Fields
underlying: Box<SearchAlgorithmConfig>path search algorithm to use
similarity: Option<RouteSimilarityFunction>if provided, filters out potential solution paths based on their similarity to the paths in the stored result set
termination: Option<KspTerminationCriteria>termination criteria for the inner path search function
Yens
K-shortest paths algorithm that relies on successive edge cuts to find alternatives to the true shortest path. Taken from the paper Yen, Jin Y. “An algorithm for finding shortest routes from all source nodes to a given destination in general networks.” Quarterly of applied mathematics 27.4 (1970): 526-530.
Fields
underlying: Box<SearchAlgorithmConfig>path search algorithm to use
similarity: Option<RouteSimilarityFunction>if provided, filters out potential solution paths based on their similarity to the paths in the stored result set
termination: Option<KspTerminationCriteria>termination criteria for the inner path search function