pub enum CustomVariableConfig {
FloatingPoint {
initial: OrderedFloat<f64>,
},
SignedInteger {
initial: i64,
},
UnsignedInteger {
initial: u64,
},
Boolean {
initial: bool,
},
}Expand description
codec between StateVar values and basic Rust types. all stateful information in Compass is encoded as a vector of floating point values. a codec provides a mapping to and from types in order to represent different real-numbered and discrete information types.
because Rust does not support dependent types and trait objects cannot return “Self“s, we are limited in how we generalize over unit types. these codecs substitute for the limitations in the type system, providing a validation check on encoding and decoding to/from StateVar instances and also a codec value that can be instantiated from configuration for a given StateModel.
warning: this could backfire, but probably in extreme cases that can be avoided. for example, if the user selects esoteric integer values that are not well-represented in floating point, then an encode -> decode roundtrip may not be idempotent.
Variants
Implementations
Sourceimpl CustomVariableConfig
impl CustomVariableConfig
pub const DEFAULT: Self
pub fn name(&self) -> String
pub fn initial(&self) -> Result<StateVariable, StateModelError>
pub fn encode_f64(&self, value: &f64) -> Result<StateVariable, StateModelError>
pub fn encode_i64(&self, value: &i64) -> Result<StateVariable, StateModelError>
pub fn encode_u64(&self, value: &u64) -> Result<StateVariable, StateModelError>
pub fn encode_bool( &self, value: &bool, ) -> Result<StateVariable, StateModelError>
pub fn decode_f64(&self, value: &StateVariable) -> Result<f64, StateModelError>
pub fn decode_i64(&self, value: &StateVariable) -> Result<i64, StateModelError>
pub fn decode_u64(&self, value: &StateVariable) -> Result<u64, StateModelError>
pub fn decode_bool( &self, value: &StateVariable, ) -> Result<bool, StateModelError>